find_integer_relation

Function find_integer_relation 

pub fn find_integer_relation(
    target: f64,
    config: &PslqConfig,
) -> Option<IntegerRelation>
Search for integer relations using PSLQ algorithm

Given a target value and a set of basis vectors (constants), find integer coefficients such that the linear combination is close to zero.

Arguments

  • target - The value to find relations for
  • config - PSLQ configuration options

Returns

An optional integer relation if one is found