EvalError

Enum EvalError 

pub enum EvalError {
    StackUnderflow,
    MissingUserConstant(usize),
    DivisionByZero,
    LogDomain,
    SqrtDomain,
    Overflow,
    Invalid,
    WithPosition {
        err: Box<EvalError>,
        pos: usize,
    },
    WithValue {
        err: Box<EvalError>,
        val: OrderedFloat<f64>,
    },
    WithExpression {
        err: Box<EvalError>,
        expr: String,
    },
}
Evaluation error types

These errors indicate what went wrong during expression evaluation. For more detailed context, use the error message methods.

Variants



StackUnderflow

Stack underflow during evaluation



MissingUserConstant(usize)

User constant slot referenced by the expression is not configured



DivisionByZero

Division by zero



LogDomain

Logarithm of non-positive number



SqrtDomain

Square root of negative number



Overflow

Overflow or NaN result



Invalid

Invalid expression



WithPosition

Error with position context

Fields

pos: usize


WithValue

Error with value context



WithExpression

Error with expression context

Fields

expr: String

Implementations

Source

impl EvalError

pub fn with_context(self, position: Option<usize>, value: Option<f64>) -> Self

Create a detailed error message with context (backward compatibility)

pub fn with_expression(self, expr: String) -> Self

Add expression context