pub struct ExprDatabase { /* private fields */ }Expand description
Database for storing expressions sorted by value Uses a flat sorted vector for cache-friendly range scans
Implementations
Sourceimpl ExprDatabase
impl ExprDatabase
pub fn new() -> Self
Sourcepub fn insert_rhs(&mut self, exprs: Vec<EvaluatedExpr>)
pub fn insert_rhs(&mut self, exprs: Vec<EvaluatedExpr>)
Insert RHS expressions into the database Sorts by value for efficient range queries using partition_point
Sourcepub fn range(&self, low: f64, high: f64) -> &[EvaluatedExpr]
pub fn range(&self, low: f64, high: f64) -> &[EvaluatedExpr]
Find RHS expressions in the value range [low, high] Returns a slice of matching expressions (contiguous, cache-friendly)
Sourcepub fn find_matches(
&self,
lhs_exprs: &[EvaluatedExpr],
config: &SearchConfig,
) -> Vec<Match>
pub fn find_matches( &self, lhs_exprs: &[EvaluatedExpr], config: &SearchConfig, ) -> Vec<Match>
Find matches for LHS expressions using streaming collection
This method is part of the public API for library consumers who want to perform matching without statistics collection.
Sourcepub fn find_matches_with_context(
&self,
lhs_exprs: &[EvaluatedExpr],
context: &SearchContext<'_>,
) -> Vec<Match>
pub fn find_matches_with_context( &self, lhs_exprs: &[EvaluatedExpr], context: &SearchContext<'_>, ) -> Vec<Match>
Find matches with an explicit per-run search context.
Sourcepub fn find_matches_with_stats(
&self,
lhs_exprs: &[EvaluatedExpr],
config: &SearchConfig,
) -> (Vec<Match>, SearchStats)
pub fn find_matches_with_stats( &self, lhs_exprs: &[EvaluatedExpr], config: &SearchConfig, ) -> (Vec<Match>, SearchStats)
Find matches with statistics collection
Sourcepub fn find_matches_with_stats_and_context(
&self,
lhs_exprs: &[EvaluatedExpr],
context: &SearchContext<'_>,
) -> (Vec<Match>, SearchStats)
pub fn find_matches_with_stats_and_context( &self, lhs_exprs: &[EvaluatedExpr], context: &SearchContext<'_>, ) -> (Vec<Match>, SearchStats)
Find matches with statistics collection using an explicit per-run search context.